@@ -12,7 +12,7 @@ def color_imbalanced(raw_input):
     if raw_input != "0.00":
         pattern = re.compile(r'(: )(\d+)')
         val = int(pattern.search(raw_input)[2])
-        if val > 90:
+        if val >= 90:
             color =  constance_object.RED
     return constance_object.OUTPUT.format(color)
 
